summaryrefslogtreecommitdiffstats
path: root/buildtools/autotools/autosubprojectview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'buildtools/autotools/autosubprojectview.cpp')
-rw-r--r--buildtools/autotools/autosubprojectview.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/buildtools/autotools/autosubprojectview.cpp b/buildtools/autotools/autosubprojectview.cpp
index 0c27eb1b..5916b332 100644
--- a/buildtools/autotools/autosubprojectview.cpp
+++ b/buildtools/autotools/autosubprojectview.cpp
@@ -156,7 +156,7 @@ void AutoSubprojectView::slotSelectionChanged( TQListViewItem* item )
void AutoSubprojectView::loadMakefileams ( const TQString& dir )
{
SubprojectItem * item = new SubprojectItem( m_listView, m_part->projectName() );
- item->setPixmap ( 0, SmallIcon ( "kdevelop" ) );
+ item->setPixmap ( 0, SmallIcon ( "tdevelop" ) );
item->subdir = "/";
item->path = dir;
parse( item );
@@ -197,7 +197,7 @@ void AutoSubprojectView::initActions()
"subprojects containing Makefile.am.</qt>"));
TQToolTip::add( m_button2, tr2i18n( "Add Target..."));
- addTargetAction = new AutoToolsAction( i18n( "Add Target..." ), "targetnew_kdevelop", 0,
+ addTargetAction = new AutoToolsAction( i18n( "Add Target..." ), "targetnew_tdevelop", 0,
TQT_TQOBJECT(this), TQT_SLOT( slotAddTarget() ), actions, "add target" );
addTargetAction->setWhatsThis(i18n( "<qt><b>Add target</b><p>Adds a new target to "
"the currently selected subproject. Target can be a "
@@ -206,7 +206,7 @@ void AutoSubprojectView::initActions()
addTargetAction->plug( m_button2 );
TQToolTip::add( m_button3, tr2i18n( "Add Service..."));
- addServiceAction = new AutoToolsAction( i18n( "Add Service..." ), "servicenew_kdevelop", 0, TQT_TQOBJECT(this),
+ addServiceAction = new AutoToolsAction( i18n( "Add Service..." ), "servicenew_tdevelop", 0, TQT_TQOBJECT(this),
TQT_SLOT( slotAddService() ), actions, "add service" );
addServiceAction->setWhatsThis(i18n("<qt><b>Add service</b><p>Creates a .desktop file describing the service.</qt>"));
addServiceAction->plug( m_button3 );
@@ -836,7 +836,7 @@ void AutoSubprojectView::parseSUBDIRS( SubprojectItem *item,
}
//search for AC_SUBST variables and try to replace them with variables
//that have been already defined e.g. in a "kdevelop hint"
varre = TQRegExp( "\\@(.*)\\@" );
varre.setMinimal( true );
while ( varre.search( subdirs ) != -1 )
@@ -836,7 +836,7 @@ void AutoSubprojectView::parseSUBDIRS( SubprojectItem *item,
}
//search for AC_SUBST variables and try to replace them with variables
- //that have been already defined e.g. in a "kdevelop hint"
+ //that have been already defined e.g. in a "tdevelop hint"
varre = TQRegExp( "\\@(.*)\\@" );
varre.setMinimal( true );